doapfiend.plugins.n3

Package doapfiend :: Package plugins :: Module n3 |
[hide private]
[frames] | no frames]

# Module n3

source code

# Serializer for N3 (Notation 3)

This is a plugin for formatting DOAP output as N3 (Notation 3) syntax.

Classes | [hide private]
| OutputPlugin Class for formatting DOAP output

Functions | [hide private]
unicode or string |
get_n3(xml_text, color=False) Return N3 (Notation 3) text Note: Returns string for non-color and unicode for colored text | source code

Variables | [hide private]
| LOG = `logging.getLogger(__name__)`

Function Details | [hide private]

### get_n3(xml_text, color=False) | source code
Return N3 (Notation 3) text Note: Returns string for non-color and unicode for colored text Parameters: `xml_text` (string) - XML/RDF Returns: unicode or string DOAP in Notation 3